define(
//begin v1.x content
({
	singleSort: "單一排序",
	nestedSort: "巢狀排序",
	ascending: "遞增",
	descending: "降冪",
	sortingState: "${0} - ${1}",
	unsorted: "請勿對此欄執行排序",
	indirectSelectionRadio: "第 ${0} 行，單一選項，圓鈕框",
	indirectSelectionCheckBox: "第 ${0} 行，多重選項，勾選框",
	selectAll: "全選"
})
//end v1.x content
);

